// MAX1238 (Analog to Digital Converter) demonstration program
// -- by diafysal

import stamp.core.*;
import stamp.peripheral.io.I2C;
import stamp.peripheral.io.MAX1238;

public class DemoMAX1238 {

  final static char CLR_SCR = '\u0010';
  final static char HOME    = 0x01;

  public static void main() {

    // create bus for I2C devices [SDA = pin2, SCL = pin1]
    I2C i2cBus = new I2C(CPU.pin2, CPU.pin1);
    // create MAX1238 object
    // -- device address is 0110 101x
    MAX1238 ADCPort = new MAX1238(i2cBus, 0x6a);

    StringBuffer msg = new StringBuffer();// create buffer for screen messages

    int analogValue;                      // storage for ADC input
    int channel = 0x02;                   // select ADC channel
                                          // 0x02 = AIN2 , pin3 on MAX1238

    // start of code
    System.out.print(CLR_SCR);
    if (ADCPort.isPresent() && ADCPort.write(0x61 | ((channel & 0x0f) << 1))) {

      while(true) {
        msg.clear();
        msg.append(HOME);
        msg.append("MAX1238 is present\n");

        analogValue = ADCPort.read();                  //Read channel.

        msg.append("Channel ");
        msg.append(channel);
        msg.append(" = ");
        msg.append(analogValue);
        msg.append("   ");

        System.out.print(msg.toString());

      }   //end while
    }   //end if
    else {
      System.out.print("Error: MAX1238 not found");
    }
  }     //end main
}